@@ -35,6 +35,17 @@ module.exports = {
       async.each(collection, iterator, callback);
     }
   },
+  'each:set': {
+    setup: function(count) {
+      collection = createSetCollection(count);
+      iterator = function(n, callback) {
+        callback();
+      };
+    },
+    func: function(async, callback) {
+      async.each(collection, iterator, callback);
+    }
+  },
   'each:map': {
     setup: function(count) {
       collection = createMapCollection(count);
@@ -230,6 +241,80 @@ module.exports = {
       async.mapLimit(collection, limit, iterator, callback);
     }
   },
+  'mapValues:array': {
+    setup: function(count) {
+      collection = createArrayCollection(count);
+      iterator = function(n, k, callback) {
+        callback(null, n);
+      };
+    },
+    func: function(async, callback) {
+      async.mapValues(collection, iterator, callback);
+    }
+  },
+  'mapValues:object': {
+    setup: function(count) {
+      collection = createObjectCollection(count);
+      iterator = function(n, k, callback) {
+        callback(null, n);
+      };
+    },
+    func: function(async, callback) {
+      async.mapValues(collection, iterator, callback);
+    }
+  },
+  'mapValuesSeries:array': {
+    setup: function(count) {
+      collection = createArrayCollection(count);
+      iterator = function(n, k, callback) {
+        process.nextTick(function() {
+          callback(null, n);
+        });
+      };
+    },
+    func: function(async, callback) {
+      async.mapValuesSeries(collection, iterator, callback);
+    }
+  },
+  'mapValuesSeries:object': {
+    setup: function(count) {
+      collection = createObjectCollection(count);
+      iterator = function(n, k, callback) {
+        process.nextTick(function() {
+          callback(null, n);
+        });
+      };
+    },
+    func: function(async, callback) {
+      async.mapValuesSeries(collection, iterator, callback);
+    }
+  },
+  'mapValuesLimit:array': {
+    setup: function(count) {
+      collection = createArrayCollection(count);
+      iterator = function(n, k, callback) {
+        process.nextTick(function() {
+          callback(null, n);
+        });
+      };
+    },
+    func: function(async, callback) {
+      async.mapValuesLimit(collection, limit, iterator, callback);
+    }
+  },
+  'mapValuesLimit:object': {
+    setup: function(count) {
+      collection = createObjectCollection(count);
+      iterator = function(n, k, callback) {
+        process.nextTick(function() {
+          callback(null, n);
+        });
+      };
+    },
+    func: function(async, callback) {
+      async.mapValuesLimit(collection, limit, iterator, callback);
+    }
+  },
   'filter:array': {
     setup: function(count) {
       collection = createArrayCollection(count);
@@ -309,7 +394,6 @@ module.exports = {
       collection = createArrayCollection(count);
       iterator = function(n, callback) {
         callback(null, n % 2);
-        callback(null, n % 2);
       };
     },
     func: function(async, callback) {
@@ -680,7 +764,9 @@ module.exports = {
     setup: function(count) {
       collection = createArrayCollection(count);
       iterator = function(n, callback) {
-        callback(null, n);
+        process.nextTick(function() {
+          callback(null, n);
+        });
       };
     },
     func: function(async, callback) {
@@ -691,7 +777,9 @@ module.exports = {
     setup: function(count) {
       collection = createObjectCollection(count);
       iterator = function(n, callback) {
-        callback(null, n);
+        process.nextTick(function() {
+          callback(null, n);
+        });
       };
     },
     func: function(async, callback) {
@@ -1141,6 +1229,14 @@ function createObjectCollection(count) {
   return _.mapValues(_.shuffle(_.times(count)));
 }
 
+function createSetCollection(count) {
+  var set = new Set();
+  _.forOwn(createArrayCollection(count), function(v) {
+    set.add(v);
+  });
+  return set;
+}
+
 function createMapCollection(count) {
   var map = new Map();
   _.forOwn(createObjectCollection(count), function(v, k) {
