@@ -69,8 +69,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -84,8 +84,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [2, 2],
         [3, 1]
@@ -107,8 +107,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -126,8 +126,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [2, 'c'],
         [3, 'b']
@@ -148,8 +148,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -165,8 +165,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [2, 2],
         [3, 1]
@@ -175,6 +175,42 @@ parallel('#concat', function() {
     });
   });
 
+  it('should work even if the size is decreased', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.concat(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.concat(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
 
   it('should execute iterator by collection of Map', function(done) {
 
@@ -188,8 +224,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['c', 2],
         ['b', 3]
@@ -210,8 +246,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         [['a', 1], 0],
         [['c', 2], 2],
         [['b', 3], 1]
@@ -234,8 +270,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1.5, 0.5, 3.5, 2.5, 1.5, 0.5, 2.5, 1.5, 0.5]);
-      assert.deepEqual(order, [1.5, 2.5, 3.5]);
+      assert.deepStrictEqual(res, [1.5, 0.5, 3.5, 2.5, 1.5, 0.5, 2.5, 1.5, 0.5]);
+      assert.deepStrictEqual(order, [1.5, 2.5, 3.5]);
       done();
     }, Math);
   });
@@ -253,8 +289,8 @@ parallel('#concat', function() {
     async.concat(collection, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 2]);
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(res, [1, 2]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -268,8 +304,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -283,7 +319,7 @@ parallel('#concat', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, array);
+      assert.deepStrictEqual(res, array);
       done();
     });
   });
@@ -297,7 +333,7 @@ parallel('#concat', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
+      assert.deepStrictEqual(res, []);
       done();
     });
   });
@@ -311,7 +347,7 @@ parallel('#concat', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [undefined, undefined, undefined]);
+      assert.deepStrictEqual(res, [undefined, undefined, undefined]);
       done();
     });
   });
@@ -324,7 +360,7 @@ parallel('#concat', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(res, [1, 2, 3]);
       done();
     });
   });
@@ -337,7 +373,7 @@ parallel('#concat', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
+      assert.deepStrictEqual(res, []);
       done();
     });
   });
@@ -374,8 +410,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -388,8 +424,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -402,8 +438,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -416,8 +452,8 @@ parallel('#concat', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -434,8 +470,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -449,8 +485,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 1],
         [2, 2]
@@ -472,8 +508,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -491,8 +527,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [3, 'b'],
         [2, 'c']
@@ -513,8 +549,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -530,8 +566,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 1],
         [2, 2]
@@ -540,6 +576,43 @@ parallel('#concatSeries', function() {
     });
   });
 
+  it('should work even if the size is decreased', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.concatSeries(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.concatSeries(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator to series by collection of Map', function(done) {
 
     var order = [];
@@ -552,8 +625,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['b', 3],
         ['c', 2]
@@ -573,8 +646,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         [['a', 1], 0],
         [['b', 3], 1],
         [['c', 2], 2]
@@ -597,8 +670,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1.5, 0.5, 3.5, 2.5, 1.5, 0.5, 2.5, 1.5, 0.5]);
-      assert.deepEqual(order, [1.5, 3.5, 2.5]);
+      assert.deepStrictEqual(res, [1.5, 0.5, 3.5, 2.5, 1.5, 0.5, 2.5, 1.5, 0.5]);
+      assert.deepStrictEqual(order, [1.5, 3.5, 2.5]);
       done();
     }, Math);
   });
@@ -619,7 +692,7 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(sync, false);
-      assert.deepEqual(result, [1, 3, 2]);
+      assert.deepStrictEqual(result, [1, 3, 2]);
       done();
     });
     sync = false;
@@ -634,7 +707,7 @@ parallel('#concatSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, array);
+      assert.deepStrictEqual(res, array);
       done();
     });
   });
@@ -648,7 +721,7 @@ parallel('#concatSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
+      assert.deepStrictEqual(res, []);
       done();
     });
   });
@@ -662,7 +735,7 @@ parallel('#concatSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [undefined, undefined, undefined]);
+      assert.deepStrictEqual(res, [undefined, undefined, undefined]);
       done();
     });
   });
@@ -675,7 +748,7 @@ parallel('#concatSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(res, [1, 2, 3]);
       done();
     });
   });
@@ -693,8 +766,8 @@ parallel('#concatSeries', function() {
     async.concatSeries(collection, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3]);
-      assert.deepEqual(order, [1, 3]);
+      assert.deepStrictEqual(res, [1, 3]);
+      assert.deepStrictEqual(order, [1, 3]);
       done();
     });
   });
@@ -754,8 +827,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -769,8 +842,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -783,8 +856,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -797,8 +870,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -811,8 +884,8 @@ parallel('#concatSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -830,8 +903,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -845,8 +918,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2],
         [5, 1],
@@ -872,8 +945,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -893,8 +966,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [3, 'c'],
         [5, 'b'],
@@ -919,8 +992,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -938,8 +1011,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2],
         [5, 1],
@@ -950,6 +1023,65 @@ parallel('#concatLimit', function() {
     });
   });
 
+  it('should work with odd number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.concatLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work with even number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5, 6]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.concatLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.concatLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator in limited by collection of Map', function(done) {
 
     var order = [];
@@ -964,8 +1096,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['c', 3],
         ['b', 5],
@@ -989,8 +1121,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 5, 4, 3, 2, 1, 3, 2, 1, 4, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [
         [ ['a', 1], 0],
         [ ['c', 3], 2],
         [ ['b', 5], 1],
@@ -1015,8 +1147,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1.5, 0.5, 3.5, 2.5, 1.5, 0.5, 2.5, 1.5, 0.5]);
-      assert.deepEqual(order, [1.5, 3.5, 2.5]);
+      assert.deepStrictEqual(res, [1.5, 0.5, 3.5, 2.5, 1.5, 0.5, 2.5, 1.5, 0.5]);
+      assert.deepStrictEqual(order, [1.5, 3.5, 2.5]);
       done();
     }, Math);
   });
@@ -1030,8 +1162,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 2, 1, 2, 1]);
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(res, [1, 3, 2, 1, 2, 1]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -1054,7 +1186,7 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(sync, false);
-      assert.deepEqual(result, [1, 3, 2, 4, 5]);
+      assert.deepStrictEqual(result, [1, 3, 2, 4, 5]);
       done();
     });
     sync = false;
@@ -1069,7 +1201,7 @@ parallel('#concatLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, array);
+      assert.deepStrictEqual(res, array);
       done();
     });
   });
@@ -1083,7 +1215,7 @@ parallel('#concatLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
+      assert.deepStrictEqual(res, []);
       done();
     });
   });
@@ -1097,7 +1229,7 @@ parallel('#concatLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [undefined, undefined, undefined]);
+      assert.deepStrictEqual(res, [undefined, undefined, undefined]);
       done();
     });
   });
@@ -1110,7 +1242,7 @@ parallel('#concatLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(res, [1, 2, 3]);
       done();
     });
   });
@@ -1129,8 +1261,8 @@ parallel('#concatLimit', function() {
     async.concatLimit(collection, 5, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 2]);
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(res, [1, 2]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -1167,8 +1299,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1182,8 +1314,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1196,8 +1328,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1210,8 +1342,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1224,8 +1356,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1239,8 +1371,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1254,8 +1386,8 @@ parallel('#concatLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
