@@ -58,7 +58,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, 1);
-      assert.deepEqual(order, [1]);
+      assert.deepStrictEqual(order, [1]);
       done();
     });
   });
@@ -72,7 +72,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, 1);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0]
       ]);
       done();
@@ -92,7 +92,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, 3);
-      assert.deepEqual(order, [2, 3]);
+      assert.deepStrictEqual(order, [2, 3]);
       done();
     });
   });
@@ -110,7 +110,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, 3);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [2, 'c'],
         [3, 'b']
       ]);
@@ -130,7 +130,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, 3);
-      assert.deepEqual(order, [2, 3]);
+      assert.deepStrictEqual(order, [2, 3]);
       done();
     });
   });
@@ -147,7 +147,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, 3);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [2, 2],
         [3, 1]
       ]);
@@ -155,6 +155,43 @@ parallel('#detect', function() {
     });
   });
 
+  it('should work even if the size is decreased', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.detect(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.detect(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator by collection of Map', function(done) {
 
     var order = [];
@@ -166,8 +203,8 @@ parallel('#detect', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, ['b', 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, ['b', 3]);
+      assert.deepStrictEqual(order, [
         ['c', 2],
         ['b', 3]
       ]);
@@ -186,8 +223,8 @@ parallel('#detect', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, ['b', 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, ['b', 3]);
+      assert.deepStrictEqual(order, [
         [ ['c', 2], 2],
         [ ['b', 3], 1]
       ]);
@@ -209,7 +246,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, 1.1);
-      assert.deepEqual(order, [1.1]);
+      assert.deepStrictEqual(order, [1.1]);
       done();
     }, Math);
   });
@@ -224,7 +261,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, [2, 4, 6]);
+      assert.deepStrictEqual(order, [2, 4, 6]);
       done();
     });
   });
@@ -329,7 +366,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -343,7 +380,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -356,7 +393,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -369,7 +406,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -382,7 +419,7 @@ parallel('#detect', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -400,7 +437,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, 1);
-      assert.deepEqual(order, [1]);
+      assert.deepStrictEqual(order, [1]);
       done();
     });
   });
@@ -414,7 +451,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, 1);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0]
       ]);
       done();
@@ -434,7 +471,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, 5);
-      assert.deepEqual(order, [5]);
+      assert.deepStrictEqual(order, [5]);
       done();
     });
   });
@@ -452,7 +489,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, 5);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [5, 'a']
       ]);
       done();
@@ -471,7 +508,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, 5);
-      assert.deepEqual(order, [5]);
+      assert.deepStrictEqual(order, [5]);
       done();
     });
   });
@@ -488,13 +525,50 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, 5);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [5, 0]
       ]);
       done();
     });
   });
 
+  it('should work even if the size is decreased', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.detectSeries(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.detectSeries(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator to series by collection of Map', function(done) {
 
     var order = [];
@@ -506,8 +580,8 @@ parallel('#detectSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, ['a', 5]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, ['a', 5]);
+      assert.deepStrictEqual(order, [
         ['a', 5]
       ]);
       done();
@@ -525,8 +599,8 @@ parallel('#detectSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, ['a', 5]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, ['a', 5]);
+      assert.deepStrictEqual(order, [
         [ ['a', 5], 0]
       ]);
       done();
@@ -547,7 +621,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, 1.1);
-      assert.deepEqual(order, [1.1]);
+      assert.deepStrictEqual(order, [1.1]);
       done();
     }, Math);
   });
@@ -584,7 +658,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, [2, 6, 4]);
+      assert.deepStrictEqual(order, [2, 6, 4]);
       done();
     });
   });
@@ -599,7 +673,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [2, 0],
         [6, 1],
         [4, 2]
@@ -708,7 +782,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -722,7 +796,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -735,7 +809,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -748,7 +822,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -761,7 +835,7 @@ parallel('#detectSeries', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -798,7 +872,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, 3);
-      assert.deepEqual(order, [2, 4, 3]);
+      assert.deepStrictEqual(order, [2, 4, 3]);
       done();
     });
   });
@@ -813,7 +887,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, 3);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [2, 0],
         [4, 1],
         [3, 2]
@@ -836,7 +910,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, 3);
-      assert.deepEqual(order, [2, 4, 3]);
+      assert.deepStrictEqual(order, [2, 4, 3]);
       done();
     });
   });
@@ -855,7 +929,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, 3);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [2, 'a'],
         [4, 'b'],
         [3, 'c']
@@ -877,7 +951,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, 3);
-      assert.deepEqual(order, [2, 4, 3]);
+      assert.deepStrictEqual(order, [2, 4, 3]);
       done();
     });
   });
@@ -895,7 +969,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, 3);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [2, 0],
         [4, 1],
         [3, 2]
@@ -904,6 +978,65 @@ parallel('#detectLimit', function() {
     });
   });
 
+  it('should work with odd number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5]);
+    var iterator = function(value, index, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.detectLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work with even number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5, 6]);
+    var iterator = function(value, index, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.detectLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.detectLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator in limited by collection of Map', function(done) {
 
     var order = [];
@@ -916,8 +1049,8 @@ parallel('#detectLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, ['c', 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, ['c', 3]);
+      assert.deepStrictEqual(order, [
         ['a', 2],
         ['b', 4],
         ['c', 3]
@@ -938,8 +1071,8 @@ parallel('#detectLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, ['c', 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, ['c', 3]);
+      assert.deepStrictEqual(order, [
         [ ['a', 2], 0],
         [ ['b', 4], 1],
         [ ['c', 3], 2]
@@ -962,7 +1095,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, 2.1);
-      assert.deepEqual(order, [2.1]);
+      assert.deepStrictEqual(order, [2.1]);
       done();
     }, Math);
   });
@@ -977,7 +1110,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, 1);
-      assert.deepEqual(order, [1]);
+      assert.deepStrictEqual(order, [1]);
       done();
     });
   });
@@ -1016,7 +1149,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, [2, 4, 8]);
+      assert.deepStrictEqual(order, [2, 4, 8]);
       done();
     });
   });
@@ -1034,7 +1167,7 @@ parallel('#detectLimit', function() {
     async.detectLimit(collection, 2, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, [1, 2, 4]);
+      assert.deepStrictEqual(order, [1, 2, 4]);
       done();
     });
   });
@@ -1122,7 +1255,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1136,7 +1269,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1149,7 +1282,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1162,7 +1295,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1175,7 +1308,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1189,7 +1322,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1203,7 +1336,7 @@ parallel('#detectLimit', function() {
         return done(err);
       }
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1220,7 +1353,7 @@ parallel('#detectLimit', function() {
       assert.strictEqual(res, 1);
     });
     setTimeout(function() {
-      assert.deepEqual(order, [1, 'callback', 2]);
+      assert.deepStrictEqual(order, [1, 'callback', 2]);
       done();
     }, 10 * delay);
   });
